textgrad.optimizer.prompts
==========================

.. automodule:: textgrad.optimizer.prompts

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      construct_tgd_prompt
   
   

   
   
   

   
   
   



